import { Message } from 'eris';
import { Client, Command } from '../class';

export default class Profile extends Command {
  constructor(client: Client) {
    super(client);
    this.name = 'profile';
    this.description = 'Manages your profile on CR';
    this.usage = 'profile <bio/github/gitlab> <new value>';
    this.permissions = 0;
    this.enabled = true;
  }

  public async run(message: Message, args: string[]) {
    const profile = await this.client.db.Member.findOne({ userID: message.author.id });
    if (!profile) return this.error(message.channel, 'Please try again later. We do not currently have a member profile for you.');
    if (!args[1]) return this.error(message.channel, 'No new value was provided.');
    const newValue = args.slice(1).join(' ');
    if (newValue.length >= 512) return this.error(message.channel, 'Please shorten your input.');

    switch (args[0]) {
      case 'github':
        await profile.updateOne({
          additional: {
            ...profile.additional,
            github: args[1],
          },
        });
        this.success(message.channel, 'Updated GitHub.');
        break;
      case 'gitlab':
        await profile.updateOne({
          additional: {
            ...profile.additional,
            gitlab: args[1],
          },
        });
        this.success(message.channel, 'Updated GitLab.');
        break;
      case 'bio':
        await profile.updateOne({
          additional: {
            ...profile.additional,
            bio: newValue,
          },
        });
        this.success(message.channel, 'Updated bio.');
        break;
      default:
        return this.error(message.channel, 'Please specify a valid option to change.');
    }
  }
}
